==> was-plugin-extensions-3.8.0.jar: wasx/resources/jdbc/create-datasource.py <==
def findJaasAuthData(alias):
  jaasAuthDatas = AdminConfig.list('JAASAuthData')
  if jaasAuthDatas == '':
    return None
  for jaasAuthData in jaasAuthDatas.splitlines():
    if AdminConfig.showAttribute(jaasAuthData, 'alias') == alias:
      return jaasAuthData
  return None

providerContainmentPath = '%s/JDBCProvider:%s' % (deployed.container.containmentPath, deployed.jdbcProvider)
providerId = validateNotEmpty(AdminConfig.getid(providerContainmentPath), "Cannot find JDBC Provider '%s' in scope %s" % (deployed.jdbcProvider, deployed.container.name))

# Create JAAS authentication data
if (deployed.jaasAliasName is None) or (deployed.jaasAliasName == ''):
  jaasName = deployed.container.shortTypeDescription + '_' + deployed.container.name + '_' + deployed.name + '_user'
else:
  jaasName = deployed.jaasAliasName
  
securityId = AdminConfig.getid("/Cell:%s/Security:/" % deployed.container.cellName)

authdataId = findJaasAuthData(jaasName)
if (authdataId is not None):
  if (deployed.allowExistingJaasAlias):
    print "WARN: Using existing JAAS/J2C authentication data with alias '%s'" % (jaasName)
  else:
    print "ERROR: JAAS/J2C authentication data with alias '%s' already exists" % (jaasName)
    sys.exit(1)
else:
  print "Creating JAAS/J2C authentication data '%s'" % (jaasName)
  authdataId = AdminConfig.create('JAASAuthData', securityId, [['alias', jaasName], ['userId', deployed.username], ['password', deployed.password]])

# Create JDBC DataSource
createParams = [["authDataAlias" , jaasName], ['name', deployed.name], ['jndiName', deployed.jndiName], ['datasourceHelperClassname', deployed.datasourceHelperClassname]]

if deployed.useJaasAliasForXaRecovery:
    createParams.append(["xaRecoveryAuthAlias" , jaasName])
if deployed.description != None:
    createParams.append(['description', deployed.description])
print "Creating JDBC DataSource %s: %s" % (deployed.name, createParams)
datasourceId = AdminConfig.create('DataSource', providerId, createParams)

# Set additional properties
propertySet = AdminConfig.create('J2EEResourcePropertySet', datasourceId, [])
for propName, propValue in deployed.getExposedProperties(True).items():
    if propValue != None:
    	if propName != 'customProperties':
	        args = [['name', propName],['value', propValue]]
	        print "Creating J2EE Resource Property: %s" % (args)
	        AdminConfig.create('J2EEResourceProperty', propertySet, args)
    	else:
	        for key, value in deployed.customProperties.items():
	            args = [['name', key], ['value', value]]
	            print "Creating J2EE Resource Property: %s" % (args)
	            AdminConfig.create("J2EEResourceProperty", propertySet, args)

# Set container-managed authentication properties
if deployed.useJaasAliasForContainerManagedAuthentication:
    mappingArgs = [['authDataAlias', jaasName], ['mappingConfigAlias', 'DefaultPrincipalMapping']]
    print "Creating MappingModule: %s" % (mappingArgs)
    AdminConfig.create('MappingModule', datasourceId, mappingArgs)

# Set connection pool properties
if hasattr(deployed, 'ConnectionPool'):
    poolArgs = toAdminConfigArgs(deployed.ConnectionPool.getExposedProperties(True))
    print "Creating ConnectionPool: %s" % (poolArgs)
    AdminConfig.create('ConnectionPool', datasourceId, poolArgs)

==> was-plugin-extensions-24.1.1.jar: wasx/resources/jdbc/create-datasource.py <==
def findJaasAuthData(alias):
  jaasAuthDatas = AdminConfig.list('JAASAuthData')
  if jaasAuthDatas == '':
    return None
  for jaasAuthData in jaasAuthDatas.splitlines():
    if AdminConfig.showAttribute(jaasAuthData, 'alias') == alias:
      return jaasAuthData
  return None

providerContainmentPath = '%s/JDBCProvider:%s' % (deployed.container.containmentPath, deployed.jdbcProvider)
providerId = validateNotEmpty(AdminConfig.getid(providerContainmentPath), "Cannot find JDBC Provider '%s' in scope %s" % (deployed.jdbcProvider, deployed.container.name))

# Create JAAS authentication data
if (deployed.jaasAliasName is None) or (deployed.jaasAliasName == ''):
  jaasName = deployed.container.shortTypeDescription + '_' + deployed.container.name + '_' + deployed.name + '_user'
else:
  jaasName = deployed.jaasAliasName
  
securityId = AdminConfig.getid("/Cell:%s/Security:/" % deployed.container.cellName)

authdataId = findJaasAuthData(jaasName)
if (authdataId is not None):
  if (deployed.allowExistingJaasAlias):
    print "WARN: Using existing JAAS/J2C authentication data with alias '%s'" % (jaasName)
  else:
    print "ERROR: JAAS/J2C authentication data with alias '%s' already exists" % (jaasName)
    sys.exit(1)
else:
  print "Creating JAAS/J2C authentication data '%s'" % (jaasName)
  authdataId = adminConfigCreate('JAASAuthData', securityId, [['alias', jaasName], ['userId', deployed.username], ['password', deployed.password]])

# Create JDBC DataSource
createParams = [["authDataAlias" , jaasName], ['name', deployed.name], ['jndiName', deployed.jndiName], ['datasourceHelperClassname', deployed.datasourceHelperClassname]]

if deployed.useJaasAliasForXaRecovery:
    createParams.append(["xaRecoveryAuthAlias" , jaasName])
if deployed.description != None:
    createParams.append(['description', deployed.description])
print "Creating JDBC DataSource %s: %s" % (deployed.name, createParams)
datasourceId = adminConfigCreate('DataSource', providerId, createParams)

# Set additional properties
propertySet = adminConfigCreate('J2EEResourcePropertySet', datasourceId, [])
for propName, propValue in deployed.getExposedProperties(True).items():
    if propValue != None:
        if propName != 'customProperties':
            args = [['name', propName],['value', propValue]]
            print "Creating J2EE Resource Property: %s" % (args)
            adminConfigCreate('J2EEResourceProperty', propertySet, args)
        else:
            for key, value in deployed.customProperties.items():
                args = [['name', key], ['value', value]]
                print "Creating J2EE Resource Property: %s" % (args)
                adminConfigCreate("J2EEResourceProperty", propertySet, args)

# Set container-managed authentication properties
if deployed.useJaasAliasForContainerManagedAuthentication:
    mappingArgs = [['authDataAlias', jaasName], ['mappingConfigAlias', 'DefaultPrincipalMapping']]
    print "Creating MappingModule: %s" % (mappingArgs)
    adminConfigCreate('MappingModule', datasourceId, mappingArgs)

# Set connection pool properties
if hasattr(deployed, 'ConnectionPool'):
    poolArgs = toAdminConfigArgs(deployed.ConnectionPool.getExposedProperties(True))
    print "Creating ConnectionPool: %s" % (poolArgs)
    adminConfigCreate('ConnectionPool', datasourceId, poolArgs)
